==> meld-library-http-undertow-0.1.4-sources.jar: ch/raffael/meldioc/library/http/server/undertow/StandardHttpServerParams.java <==
/*
 *  Copyright (c) 2019 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.library.http.server.undertow;

/**
 * Some constants encouraging some conventions in configuration parameters.
 */
public final class StandardHttpServerParams {

  private StandardHttpServerParams() {
  }

  /**
   * Use a generic "http-server" prefix for generic HTTP server parameters
   * (port, bind address).
   */
  public static final String PREFIX = "http-server";

  public static final String PORT = PREFIX + ".port";
  public static final String ADDRESS = PREFIX + ".bind-address";

  public static final String ADR_LOCAL = "127.0.0.1";
  public static final String ADR_ALL = "0.0.0.0";
}

==> meld-library-http-undertow-0.2.0-sources.jar: ch/raffael/meldioc/library/http/server/undertow/StandardHttpServerParams.java <==
/*
 *  Copyright (c) 2022 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.library.http.server.undertow;

/**
 * Some constants encouraging some conventions in configuration parameters.
 */
public final class StandardHttpServerParams {

  private StandardHttpServerParams() {
  }

  /**
   * Use a generic "http-server" prefix for generic HTTP server parameters
   * (port, bind address).
   */
  public static final String PREFIX = UndertowServerFeature.UNDERTOW_PARAM_PREFIX;

  public static final String PORT_BASENAME = "port";
  public static final String ADDRESS_BASENAME = "bind-address";
  public static final String PORT_ABSOLUTE = PREFIX + "." + PORT_BASENAME;
  public static final String ADDRESS_ABSOLUTE = PREFIX + "." + ADDRESS_BASENAME;

  public static final String ADDRESS_LOCAL = "127.0.0.1";
  public static final String ADDRESS_ALL = "0.0.0.0";
}
